==> ThbgmExtractor-1.4.6.tar.bz2: ThbgmExtractor-1.4.6/core/Smdn.Windows.Forms.ThbgmPlayer/Smdn.Windows.Forms.ThbgmPlayer/Track.cs <==
﻿// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2009 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.ComponentModel;

using Smdn.Formats.Thbgm;

namespace Smdn.Windows.Forms.ThbgmPlayer {
  public class Track : ICloneable {
    public TrackInfo TrackInfo {
      get; private set;
    }

    public Effect Effect {
      get; private set;
    }

    public bool IsDirty {
      get; private set;
    }

    public bool Checked {
      get; internal set;
    }

    public Track(TrackInfo trackInfo)
      : this(trackInfo, Effect.CreateDefault(trackInfo), true)
    {
    }

    public Track(TrackInfo trackInfo, Effect effect, bool @checked)
    {
      this.TrackInfo = trackInfo;
      this.Effect = effect;
      this.Effect.PropertyChanged += delegate {
        IsDirty = true;
      };
      this.Checked = @checked;
    }

    object ICloneable.Clone()
    {
      return Clone();
    }

    public virtual Track Clone()
    {
      var cloned = (Track)MemberwiseClone();

      cloned.Effect = this.Effect.Clone();

      return cloned;
    }

    public EffectAppliedBgmStream GetStream(string bgmSourcePath)
    {
      if (bgmSourcePath == null)
        return TrackInfo.GetStream<EffectAppliedBgmStream>(Repeat.Infinite, Effect);
      else
        return TrackInfo.GetStream<EffectAppliedBgmStream>(bgmSourcePath, Repeat.Infinite, Effect);
    }

    public EffectAppliedBgmStream GetStream(string bgmSourcePath, int bufferSize)
    {
      if (bgmSourcePath == null)
        return TrackInfo.GetStream<EffectAppliedBgmStream>(Repeat.Infinite, Effect, bufferSize);
      else
        return TrackInfo.GetStream<EffectAppliedBgmStream>(bgmSourcePath, Repeat.Infinite, Effect, bufferSize);
    }

    internal void SetDirty()
    {
      IsDirty = true;
    }

    public void ClearDirty()
    {
      IsDirty = false;
    }
  }
}

==> ThbgmExtractor-1.6.0.tar.bz2: ThbgmExtractor-1.6.0/core/Smdn.Windows.Forms.ThbgmPlayer/Smdn.Windows.Forms.ThbgmPlayer/Track.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2013 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.ComponentModel;

using Smdn.Formats.Thbgm;

namespace Smdn.Windows.Forms.ThbgmPlayer {
  public class Track : ICloneable {
    public TrackInfo TrackInfo {
      get; private set;
    }

    public Effect Effect {
      get; private set;
    }

    public bool IsDirty {
      get; private set;
    }

    public bool Checked {
      get; internal set;
    }

    public Track(TrackInfo trackInfo)
      : this(trackInfo, Effect.CreateDefault(trackInfo), true)
    {
    }

    public Track(TrackInfo trackInfo, Effect effect, bool @checked)
    {
      this.TrackInfo = trackInfo;
      this.Effect = effect;
      this.Effect.PropertyChanged += delegate {
        IsDirty = true;
      };
      this.Checked = @checked;
    }

    object ICloneable.Clone()
    {
      return Clone();
    }

    public virtual Track Clone()
    {
      var cloned = (Track)MemberwiseClone();

      cloned.Effect = this.Effect.Clone();

      return cloned;
    }

    public EffectAppliedBgmStream GetStream(string bgmSourcePath)
    {
      if (bgmSourcePath == null)
        return TrackInfo.GetStream<EffectAppliedBgmStream>(Repeat.Infinite, Effect);
      else
        return TrackInfo.GetStream<EffectAppliedBgmStream>(bgmSourcePath, Repeat.Infinite, Effect);
    }

    public EffectAppliedBgmStream GetStream(string bgmSourcePath, bool loadOnMemory, int bufferSize)
    {
      if (bgmSourcePath == null)
        return TrackInfo.GetStream<EffectAppliedBgmStream>(Repeat.Infinite, loadOnMemory, Effect, bufferSize);
      else
        return TrackInfo.GetStream<EffectAppliedBgmStream>(bgmSourcePath, Repeat.Infinite, loadOnMemory, Effect, bufferSize);
    }

    internal void SetDirty()
    {
      IsDirty = true;
    }

    public void ClearDirty()
    {
      IsDirty = false;
    }
  }
}
